@@ -1,18 +1,18 @@
 package org.broadinstitute.barclay.help;
 
-import com.sun.javadoc.ClassDoc;
-import com.sun.javadoc.FieldDoc;
-
+import jdk.javadoc.doclet.DocletEnvironment;
 import org.apache.commons.lang3.tuple.Pair;
 
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 import org.broadinstitute.barclay.argparser.*;
+import org.broadinstitute.barclay.help.scanners.JavaLanguageModelScanners;
 import org.broadinstitute.barclay.utils.Utils;
 
+import javax.lang.model.element.Element;
+import javax.lang.model.element.ElementKind;
 import java.lang.reflect.*;
 import java.util.*;
-import java.util.stream.Collectors;
 
 
 /**
@@ -65,9 +65,7 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
             }
             if (summary == null || summary.isEmpty()) {
                 // If no summary was found from annotations, use the javadoc if there is any
-                summary = Arrays.stream(workUnit.getClassDoc().firstSentenceTags())
-                        .map(tag -> tag.text())
-                        .collect(Collectors.joining());
+                summary = JavaLanguageModelScanners.getDocCommentFirstSentence(getDoclet().getDocletEnv(), workUnit.getDocElement());
             }
         }
 
@@ -130,10 +128,7 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
      * @return Description to be used or the work unit.
      */
     protected String getDescription(final DocWorkUnit currentWorkUnit) {
-        return Arrays.stream(currentWorkUnit.getClassDoc().inlineTags())
-                .filter(t -> getTagPrefix() == null || !t.name().startsWith(getTagPrefix()))
-                .map(t -> t.text())
-                .collect(Collectors.joining());
+        return JavaLanguageModelScanners.getDocComment(getDoclet().getDocletEnv(), currentWorkUnit.getDocElement());
     }
 
     /**
@@ -194,7 +189,7 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
         // to the format's reader/writer class (i.e. TableReader), and then reference that feature
         // in the extraDocs attribute in a CommandLineProgram that reads/writes that format.
         try {
-            final Object argumentContainer = workUnit.getClazz().newInstance();
+            final Object argumentContainer = workUnit.getClazz().getDeclaredConstructor().newInstance();
             if (argumentContainer instanceof CommandLinePluginProvider) {
                 pluginDescriptors = ((CommandLinePluginProvider) argumentContainer).getPluginDescriptors();
                 clp = new CommandLineArgumentParser(
@@ -203,21 +198,23 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
             } else {
                 clp = new CommandLineArgumentParser(argumentContainer);
             }
-        } catch (IllegalAccessException | InstantiationException e) {
-            // DocumentedFeature does not assume a no-arg constructor unless it is also annotated with CommandLineProgramProperties
-            if (workUnit.getCommandLineProperties() != null) {
-                throw new RuntimeException(workUnit.getClazz() + " requires a non-arg constructor, because it is annotated with CommandLineProgramProperties ", e);
-            }
+            workUnit.setProperty("groups", groupMaps);
+            workUnit.setProperty("data", featureMaps);
+
+            addHighLevelBindings(workUnit);
+            addCommandLineArgumentBindings(workUnit, clp);
+            addDefaultPlugins(workUnit, pluginDescriptors);
+            addExtraDocsBindings(workUnit);
+            addCustomBindings(workUnit);
+        } catch (final NoSuchMethodException e) {
+            throw new CommandLineException.CommandLineParserInternalException(
+                    String.format ("DocumentedFeature class %s does not have the required no argument constructor",
+                            workUnit.getClazz()), e);
+        } catch (final InvocationTargetException | IllegalAccessException | InstantiationException e) {
+            throw new CommandLineException.CommandLineParserInternalException(
+                    String.format ("DocumentedFeature class %s cannot be instantiated",
+                            workUnit.getClazz()), e);
         }
-
-        workUnit.setProperty("groups", groupMaps);
-        workUnit.setProperty("data", featureMaps);
-
-        addHighLevelBindings(workUnit);
-        addCommandLineArgumentBindings(workUnit, clp);
-        addDefaultPlugins(workUnit, pluginDescriptors);
-        addExtraDocsBindings(workUnit);
-        addCustomBindings(workUnit);
     }
 
     /**
@@ -239,6 +236,9 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
         workUnit.setProperty(TemplateProperties.FEATURE_DEPRECATED, workUnit.isDeprecatedFeature());
         workUnit.setProperty(TemplateMapConstants.FEATURE_DEPRECATION_DETAIL, workUnit.getDeprecationDetail());
 
+        //this property is called "description" for work units, but "fulltext" for arguments). ideally
+        // these would be unified, but it would require a lot of downstream changes to templates and test
+        // result expected files
         workUnit.setProperty("description", getDescription(workUnit));
 
         workUnit.setProperty("version", getDoclet().getBuildVersion());
@@ -253,14 +253,25 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
      */
     protected void addCustomBindings(final DocWorkUnit currentWorkUnit) {
         final String tagFilterPrefix = getTagPrefix();
-        Arrays.stream(currentWorkUnit.getClassDoc().inlineTags())
-                .filter(t -> t.name().startsWith(tagFilterPrefix))
-                .forEach(t -> currentWorkUnit.setProperty(t.name().substring(tagFilterPrefix.length()), t.text()));
+        if (tagFilterPrefix != null) {
+            final Map<String, List<String>> parts = JavaLanguageModelScanners.getUnknownInlineTags(
+                    getDoclet().getDocletEnv(),
+                    currentWorkUnit.getDocElement());
+            // create properties for any custom tags
+            parts.entrySet()
+                    .stream()
+                    // we only want the tags that start with a (doclet specific) custom tag prefix; skip the
+                    // leading '@' since the scanner strips that out
+                    .filter(e -> e.getKey().startsWith(tagFilterPrefix.substring(1)))
+                    .forEach(e -> currentWorkUnit.setProperty(
+                            e.getKey().substring(tagFilterPrefix.substring(1).length()),
+                            String.join(" ", (e.getValue()))));
+        }
     }
 
     /**
      * Subclasses override this to have javadoc tags with this prefix placed in the freemarker map.
-     * @return string refix used for custom javadoc tags
+     * @return string prefix used for custom javadoc tags
      */
     protected String getTagFilterPrefix(){ return ""; }
 
@@ -324,9 +335,10 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
     }
 
     private String getTagPrefix() {
-        String customPrefix = getTagFilterPrefix();
-        return customPrefix == null ?
-                customPrefix : "@" + customPrefix + ".";
+        final String customPrefix = getTagFilterPrefix();
+        return customPrefix == null || customPrefix.length() == 0 ?
+                null :
+                "@" + customPrefix + ".";
 
     }
 
@@ -373,8 +385,8 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
         // processNamedArgument and provide an alternative policy.
         if (!argDef.isControlledByPlugin() && (!argDef.isHidden() || getDoclet().showHiddenFeatures())) {
             final Map<String, Object> argMap = new HashMap<>();
-            final FieldDoc fieldDoc = getFieldDocForCommandLineArgument(currentWorkUnit, argDef);
-            final String argKind = processNamedArgument(argMap, argDef, fieldDoc.commentText());
+            final String commentText = getDocCommentForField(currentWorkUnit, argDef);
+            final String argKind = processNamedArgument(argMap, argDef, commentText);
 
             // Finalize argument bindings
             args.get(argKind).add(argMap);
@@ -385,55 +397,41 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
         }
     }
 
-    private FieldDoc getFieldDocForCommandLineArgument(
-            final DocWorkUnit currentWorkUnit,
-            final NamedArgumentDefinition argDef)
-    {
-        // Retrieve the ClassDoc corresponding to this argument directly
-        final String declaringClassTypeName = argDef.getUnderlyingField().getDeclaringClass().getTypeName();
-        final ClassDoc declaringClassDoc = getDoclet().getRootDoc().classNamed(declaringClassTypeName);
-
-        if (declaringClassDoc == null) {
-            throw new DocException(
-                    String.format("Can't resolve ClassDoc for declaring class for argument \"%s\" in \"%s\" with qualified name \"%s\"",
-                            argDef.getUnderlyingField().getName(),
-                            currentWorkUnit.getClassDoc().qualifiedTypeName(),
-                            declaringClassTypeName));
-        }
-
-        final FieldDoc fieldDoc = getFieldDoc(declaringClassDoc, argDef.getUnderlyingField().getName());
-
-        if (fieldDoc == null) {
-            throw new DocException(
-                    String.format(
-                        "The class \"%s\" is referenced by \"%s\", and must be included in the list of documentation sources.",
-                        argDef.getUnderlyingField().getDeclaringClass().getCanonicalName(),
-                        currentWorkUnit.getClassDoc().qualifiedTypeName())
-            );
-        }
-
-        // Try to validate that the FieldDoc we found is the correct one. The qualified name of the argument's
-        // FieldDoc should start with the the normalized name of the argument's declaring class.
-        final String normalizedTypeName = declaringClassTypeName.replace('$', '.');
-        if (!fieldDoc.qualifiedName().startsWith(normalizedTypeName)) {
-            // The qualified name for a FieldDoc doesn't include the full path of the class if it corresponds to
-            // an argument who's declaring class is local/anonymous
-            if (argDef.getUnderlyingField().getDeclaringClass().isLocalClass() || argDef.getUnderlyingField().getDeclaringClass().isAnonymousClass()) {
-                logger.warn(String.format(
-                        "Field level Javadoc is ignored for local/anonymous class for member field \"%s\" in \"%s\" of type \"%s\".",
-                        argDef.getUnderlyingField().getName(),
-                        currentWorkUnit.getClazz().getCanonicalName(),
-                        declaringClassTypeName));
-            } else {
-                logger.warn(String.format(
-                        "Can't validate FieldDoc \"%s\" for member field \"%s\" in \"%s\" of type \"%s\".",
-                        fieldDoc.qualifiedName(),
-                        argDef.getUnderlyingField().getName(),
-                        currentWorkUnit.getClazz().getCanonicalName(),
-                        declaringClassTypeName));
+    private String getDocCommentForField(final DocWorkUnit workUnit, final NamedArgumentDefinition argDef) {
+        // first, see if the field (@Argument) we're looking for is declared directly in the work unit's class
+        Element fieldElement = JavaLanguageModelScanners.getElementForField(
+                getDoclet().getDocletEnv(),
+                workUnit.getDocElement(),
+                argDef.getUnderlyingField(),
+                ElementKind.FIELD);
+        if (fieldElement == null) {
+            // the field isn't defined directly in the workunit's enclosing class/element, so it must be
+            // defined in a class that is referenced by the workunit's enclosing class. find that class and get
+            // it's type element
+            Class<?> containingClass = argDef.getUnderlyingField().getDeclaringClass();
+            if (containingClass != null) {
+                String className = containingClass.getCanonicalName();
+                // className can be null if the containing class is an anonymous class, in which case we don't
+                // want to traverse the containment hierarchy because we'll just wind up back at the work unit
+                // class, which we don't want, so in order to be compatible with the way the old javadoc used
+                // to work, just bail...
+                if (className != null) {
+                    final Element classElement = getDoclet().getDocletEnv().getElementUtils().getTypeElement(className);
+                    fieldElement = JavaLanguageModelScanners.getElementForField(
+                            getDoclet().getDocletEnv(),
+                            classElement,
+                            argDef.getUnderlyingField(),
+                            ElementKind.FIELD);
+                }
             }
         }
-        return fieldDoc;
+
+        String comment = "";
+        if (fieldElement != null) {
+            comment = JavaLanguageModelScanners.getDocCommentWithoutTags(getDoclet().getDocletEnv(), fieldElement);
+        }
+        return comment;
+
     }
 
     /**
@@ -582,48 +580,6 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
         }
     }
 
-    /**
-     * Recursive helper routine to getFieldDoc()
-     */
-    private FieldDoc getFieldDoc(final ClassDoc classDoc, final String argumentFieldName) {
-        for (final FieldDoc fieldDoc : classDoc.fields(false)) {
-            if (fieldDoc.name().equals(argumentFieldName)) {
-                return fieldDoc;
-            }
-
-            // This can return null, specifically, we can encounter https://bugs.openjdk.java.net/browse/JDK-8033735,
-            // which is fixed in JDK9 http://hg.openjdk.java.net/jdk9/jdk9/hotspot/rev/ba8c351b7096.
-            final Field field = DocletUtils.getFieldForFieldDoc(fieldDoc);
-            if (field == null) {
-                logger.warn(
-                    String.format(
-                        "Could not access the field definition for %s while searching for %s, presumably because the field is inaccessible",
-                        fieldDoc.name(),
-                            argumentFieldName)
-                );
-            } else if (field.isAnnotationPresent(ArgumentCollection.class)) {
-                final ClassDoc typeDoc = getDoclet().getRootDoc().classNamed(fieldDoc.type().qualifiedTypeName());
-                if (typeDoc == null) {
-                    throw new DocException("Tried to get javadocs for ArgumentCollection field " +
-                            fieldDoc + " but couldn't find the class in the RootDoc");
-                } else {
-                    FieldDoc result = getFieldDoc(typeDoc, argumentFieldName);
-                    if (result != null) {
-                        return result;
-                    }
-                    // else keep searching
-                }
-            }
-        }
-
-        // if we didn't find it here, wander up to the superclass to find the field
-        if (classDoc.superclass() != null) {
-            return getFieldDoc(classDoc.superclass(), argumentFieldName);
-        }
-
-        return null;
-    }
-
     /**
      * Returns a Pair of (main, synonym) names for argument with fullName s1 and
      * shortName s2.
@@ -684,7 +640,7 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
      *
      * @param argBindings the argument property bindings map to be populated for this argument
      * @param argDef the {@link NamedArgumentDefinition} for this argument
-     * @param fieldCommentText the comment text for the underlying Field for the arugment, if any
+     * @param fieldCommentText the comment text for the underlying Field for the argument, if any
      * @return the "kind" category for this argument as used by the freemarker template ("deprecated", "required"
      * (common or otherwise), "common" (optional), "advanced", or "hidden")
      */
@@ -798,7 +754,7 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
         }
 
         return targetClass.isEnum() ?
-                docForEnumArgument(targetClass) :
+                docForEnumArgument(argDef, targetClass) :
                 Collections.emptyList();
     }
 
@@ -806,29 +762,53 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
      * Helper routine that provides a FreeMarker map for an enumClass, grabbing the
      * values of the enum and their associated javadoc or {@link CommandLineArgumentParser.ClpEnum} documentation.
      *
+     * @param argDef argument definition for the argument of the enum type
      * @param enumClass an enum Class that may optionally implement {@link CommandLineArgumentParser.ClpEnum}
      * @return a List of maps with keys for "name" and "summary" for each of the class's possible enum constants
+     * @param <T> type param for this enum
+     *
      */
     @SuppressWarnings("unchecked")
-    private <T extends Enum<T>> List<Map<String, String>> docForEnumArgument(final Class<?> enumClass) {
-        final ClassDoc doc = this.getDoclet().getClassDocForClass(enumClass);
-        if ( doc == null ) {
-            throw new RuntimeException(String.format("Unable to get ClassDoc for enum %s", enumClass));
-        }
-
+    private <T extends Enum<T>> List<Map<String, String>> docForEnumArgument(
+            final ArgumentDefinition argDef,
+            final Class<?> enumClass) {
         final List<Map<String, String>> bindings = new ArrayList<>();
+        final T[] enumConstants = (T[]) enumClass.getEnumConstants();
         if (CommandLineArgumentParser.ClpEnum.class.isAssignableFrom(enumClass)) {
-            final T[] enumConstants = (T[]) enumClass.getEnumConstants();
             for ( final T enumConst : enumConstants ) {
                 bindings.add(createPossibleValuesMap(
                         enumConst.name(),
                         ((CommandLineArgumentParser.ClpEnum) enumConst).getHelpDoc()));
             }
         } else {
-            final Set<String> enumConstantFieldNames = enumConstantsNames(enumClass);
-            for (final FieldDoc fieldDoc : doc.fields(false)) {
-                if (enumConstantFieldNames.contains(fieldDoc.name())) {
-                    bindings.add(createPossibleValuesMap(fieldDoc.name(), fieldDoc.commentText()));
+            final String canonicalClassName = enumClass.getCanonicalName();
+            final Element enumClassElement = getDoclet().getDocletEnv().getElementUtils().getTypeElement(canonicalClassName);
+            if (enumClassElement != null ) {
+                for ( final T enumConst : enumConstants ) {
+                    final Field enumConstField = getFieldForEnumConstant(enumClass, enumConst.name());
+                    if (enumConstField != null) {
+                        final Element fieldElement = JavaLanguageModelScanners.getElementForField(
+                                getDoclet().getDocletEnv(),
+                                enumClassElement,
+                                enumConstField,
+                                ElementKind.ENUM_CONSTANT);
+                        if (fieldElement != null) {
+                            final String comment = JavaLanguageModelScanners.getDocCommentWithoutTags(
+                                    getDoclet().getDocletEnv(),
+                                    fieldElement);
+                            bindings.add(createPossibleValuesMap(
+                                    enumConst.name(),
+                                    comment));
+                        } else {
+                            bindings.add(createPossibleValuesMap(
+                                    enumConst.name(),
+                                    "")); // empty string since there is no detail
+                        }
+                    } else {
+                        bindings.add(createPossibleValuesMap(
+                                enumConst.name(),
+                                "No documentation available"));
+                    }
                 }
             }
         }
@@ -836,6 +816,15 @@ public class DefaultDocWorkUnitHandler extends DocWorkUnitHandler {
         return bindings;
     }
 
+    private <T> Field getFieldForEnumConstant(final Class<?> enumClass, final String enumConstantName) {
+        for (final Field enumClassField : enumClass.getFields()) {
+            if (enumClassField.getName().equals(enumConstantName)) {
+                return enumClassField;
+            }
+        }
+        return null;
+    }
+
     private HashMap<String, String> createPossibleValuesMap(final String name, final String summary) {
         return new HashMap<String, String>() {
             static final long serialVersionUID = 0L;
