@@ -1,6 +1,5 @@
 package org.broadinstitute.barclay.help;
 
-import com.sun.javadoc.ClassDoc;
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 import org.broadinstitute.barclay.argparser.CommandLineException;
@@ -11,6 +10,8 @@ import org.broadinstitute.barclay.argparser.DeprecatedFeature;
 import org.broadinstitute.barclay.argparser.ExperimentalFeature;
 import org.broadinstitute.barclay.utils.Utils;
 
+import javax.lang.model.element.Element;
+import java.lang.reflect.InvocationTargetException;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -21,10 +22,10 @@ import java.util.Map;
 public class DocWorkUnit implements Comparable<DocWorkUnit> {
     final protected static Logger logger = LogManager.getLogger(DocWorkUnit.class);
 
-    private final String name;                          // name of the this work unit/feature
+    private final String name;                          // name of this work unit/feature
 
     private final Class<?> clazz;                       // class that's being documented
-    private final ClassDoc classDoc;                    // javadoc documentation for clazz
+    private final Element docElement;                  // javadoc documentation for clazz
     private final DocWorkUnitHandler workUnitHandler;   // handler for this work unit
 
     // Annotations attached to the feature class being documented by this work unit
@@ -43,19 +44,19 @@ public class DocWorkUnit implements Comparable<DocWorkUnit> {
 
     /**
      * @param workUnitHandler
-     * @param documentedFeatureAnnotation
-     * @param classDoc
+     * @param docElement
      * @param clazz
+     * @param documentedFeatureAnnotation
      */
     public DocWorkUnit(
             final DocWorkUnitHandler workUnitHandler,
-            final DocumentedFeature documentedFeatureAnnotation,
-            final ClassDoc classDoc,
-            final Class<?> clazz)
+            final Element docElement,
+            final Class<?> clazz,
+            final DocumentedFeature documentedFeatureAnnotation)
     {
         Utils.nonNull(workUnitHandler, "workUnitHandler cannot be null");
         Utils.nonNull(documentedFeatureAnnotation, "DocumentedFeature annotation cannot be null");
-        Utils.nonNull(classDoc, "classDoc cannot be null");
+        Utils.nonNull(docElement, "classDoc cannot be null");
         Utils.nonNull(clazz, "class cannot be null");
 
         this.name = clazz.getSimpleName();
@@ -68,7 +69,7 @@ public class DocWorkUnit implements Comparable<DocWorkUnit> {
         checkForMultipleMutexAnnotations();
 
         this.workUnitHandler = workUnitHandler;
-        this.classDoc = classDoc;
+        this.docElement = docElement;
         this.clazz = clazz;
 
         // summary, groupName and groupSummary can each be determined via fallback policies dictated
@@ -77,6 +78,7 @@ public class DocWorkUnit implements Comparable<DocWorkUnit> {
         summary = workUnitHandler.getSummaryForWorkUnit(this);
         groupName = workUnitHandler.getGroupNameForWorkUnit(this);
         groupSummary = workUnitHandler.getGroupSummaryForWorkUnit(this);
+
     }
 
     private void checkForMultipleMutexAnnotations() {
@@ -124,10 +126,10 @@ public class DocWorkUnit implements Comparable<DocWorkUnit> {
     public DocumentedFeature getDocumentedFeature() { return documentedFeature; }
 
     /**
-     * Get the JavDoc ClassDoc for this work unit.
-     * @return ClassDoc for this work unit. Will not be null.
+     * Get the Java language Element for this work unit.
+     * @return Element for this work unit. Will not be null.
      */
-    public ClassDoc getClassDoc() { return classDoc; }
+    public Element getDocElement() { return docElement; }
 
     /**
      * The name of this documentation unit
@@ -214,8 +216,12 @@ public class DocWorkUnit implements Comparable<DocWorkUnit> {
     public CommandLineProgramGroup getCommandLineProgramGroup() {
         if (commandLineProperties != null) {
             try {
-                return commandLineProperties.programGroup().newInstance();
-            } catch (IllegalAccessException | InstantiationException e) {
+                return commandLineProperties.programGroup().getDeclaredConstructor().newInstance();
+            } catch (final NoSuchMethodException e) {
+                throw new CommandLineException.CommandLineParserInternalException(
+                        String.format ("Command line program class %s does not have the required no argument constructor",
+                                getClazz()), e);
+            } catch (final InvocationTargetException |IllegalAccessException | InstantiationException e) {
                 logger.warn(
                         String.format("Can't instantiate program group class to retrieve summary for group %s for class %s",
                                 commandLineProperties.programGroup().getName(),
@@ -231,4 +237,47 @@ public class DocWorkUnit implements Comparable<DocWorkUnit> {
     public int compareTo(DocWorkUnit other) {
         return this.name.compareTo(other.name);
     }
+
+    @Override
+    public boolean equals(Object o) {
+        if (this == o) return true;
+        if (!(o instanceof DocWorkUnit)) return false;
+
+        DocWorkUnit that = (DocWorkUnit) o;
+
+        if (!name.equals(that.name)) return false;
+        if (!clazz.equals(that.clazz)) return false;
+        if (!docElement.equals(that.docElement)) return false;
+        if (documentedFeature != null ? !documentedFeature.equals(that.documentedFeature) :
+                that.documentedFeature != null)
+            return false;
+        if (commandLineProperties != null ? !commandLineProperties.equals(that.commandLineProperties) :
+                that.commandLineProperties != null)
+            return false;
+        if (experimentalFeature != null ? !experimentalFeature.equals(that.experimentalFeature) :
+                that.experimentalFeature != null)
+            return false;
+        if (betaFeature != null ? !betaFeature.equals(that.betaFeature) : that.betaFeature != null) return false;
+        if (!propertyMap.equals(that.propertyMap)) return false;
+        if (summary != null ? !summary.equals(that.summary) : that.summary != null) return false;
+        if (groupName != null ? !groupName.equals(that.groupName) : that.groupName != null) return false;
+        return groupSummary != null ? groupSummary.equals(that.groupSummary) : that.groupSummary == null;
+    }
+
+    @Override
+    public int hashCode() {
+        int result = name.hashCode();
+        result = 31 * result + clazz.hashCode();
+        result = 31 * result + docElement.hashCode();
+        result = 31 * result + (documentedFeature != null ? documentedFeature.hashCode() : 0);
+        result = 31 * result + (commandLineProperties != null ? commandLineProperties.hashCode() : 0);
+        result = 31 * result + (experimentalFeature != null ? experimentalFeature.hashCode() : 0);
+        result = 31 * result + (betaFeature != null ? betaFeature.hashCode() : 0);
+        result = 31 * result + propertyMap.hashCode();
+        result = 31 * result + (summary != null ? summary.hashCode() : 0);
+        result = 31 * result + (groupName != null ? groupName.hashCode() : 0);
+        result = 31 * result + (groupSummary != null ? groupSummary.hashCode() : 0);
+        return result;
+    }
+
 }
