@@ -1,5 +1,6 @@
 package org.broadinstitute.barclay.argparser;
 
+import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.tuple.Pair;
 
 import org.testng.Assert;
@@ -14,6 +15,7 @@ import java.util.*;
 import java.util.function.Consumer;
 
 public final class CommandLineArgumentParserTest {
+
     enum FrobnicationFlavor {
         FOO, BAR, BAZ
     }
@@ -27,6 +29,7 @@ public final class CommandLineArgumentParserTest {
         @ArgumentCollection
         SpecialArgumentsCollection specialArgs = new SpecialArgumentsCollection();
 
+        @DeprecatedFeature
         @PositionalArguments(minElements=2, maxElements=2)
         public List<File> positionalArguments = new ArrayList<>();
 
@@ -41,6 +44,10 @@ public final class CommandLineArgumentParserTest {
 
         @Argument
         public Boolean TRUTHINESS = false;
+
+        @Argument(doc="A deprecated argument", optional = true)
+        @DeprecatedFeature
+        public String deprecatedString;
     }
 
     @CommandLineProgramProperties(
@@ -107,6 +114,12 @@ public final class CommandLineArgumentParserTest {
                         "--FROBNICATION_THRESHOLD,-T <Integer>",
                         "--TRUTHINESS <Boolean>")
                 },
+                {
+                        new FrobnicateArguments(), Arrays.asList(
+                            "--deprecatedString",
+                            "This argument is DEPRECATED",
+                            "and will be removed in a future")
+                },
                 {
                     new MixedCardinalityMutexArguments(), Arrays.asList(
                         "--collection <String>",
@@ -530,6 +543,19 @@ public final class CommandLineArgumentParserTest {
         clp.parseArguments(System.err, args);
     }
 
+    @Test
+    public void testPositionalDeprecated() {
+        final String[] args = {
+                "mypositionalFile1.txt", "mypositionalFile1.txt",
+                "--FROBNICATION_FLAVOR", "BAR",
+                "--SHMIGGLE_TYPE", "shmiggle1",
+        };
+        final FrobnicateArguments fo = new FrobnicateArguments();
+        final CommandLineArgumentParser clp = new CommandLineArgumentParser(fo);
+        final String usage = clp.usage(true, true);
+        Assert.assertTrue(usage.contains("DEPRECATED"));
+    }
+
     @Test(expectedExceptions = CommandLineException.class)
     public void testArgumentUseClash() {
         final String[] args = {
@@ -1398,6 +1424,35 @@ public final class CommandLineArgumentParserTest {
         Assert.assertEquals(result.substring(0, expected.length()), expected);
     }
 
+    protected static class ArgumentsWithSameAndDifferentShortNames{
+        final static String REPEATED = "repeated";
+        public static final String NOT_REPEATED = "notRepeated";
+        public static final String NR = "nr";
+        public static final String ONLY_FULL_NAME = "onlyFullName";
+        @Argument(fullName = REPEATED, shortName = REPEATED)
+        String repeated;
+
+        @Argument(fullName = NOT_REPEATED, shortName = NR)
+        String notRepeated;
+
+        @Argument(fullName = ONLY_FULL_NAME)
+        String onlyFullName;
+    }
+
+    @Test
+    public void testOnlyPrintNameOnce() {
+        final CommandLineArgumentParser clp = new CommandLineArgumentParser(new ArgumentsWithSameAndDifferentShortNames());
+
+        final ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
+        final PrintStream stream = new PrintStream(byteArrayOutputStream);
+        stream.append(clp.usage(true, true));
+
+        final String result = byteArrayOutputStream.toString();
+        Assert.assertEquals(StringUtils.countMatches(result, "-"+ArgumentsWithSameAndDifferentShortNames.REPEATED), 1,result);
+        Assert.assertEquals(StringUtils.countMatches(result, "-"+ArgumentsWithSameAndDifferentShortNames.NOT_REPEATED), 1, result);
+        Assert.assertEquals(StringUtils.countMatches(result, "-"+ArgumentsWithSameAndDifferentShortNames.NR), 1, result);
+        Assert.assertEquals(StringUtils.countMatches(result, "-"+ArgumentsWithSameAndDifferentShortNames.ONLY_FULL_NAME), 1, result);
+    }
 
     /***************************************************************************************
      * End of tests and helper classes for CommandLineParser.gatherArgumentValuesOfType()
